<?php
/**
 * Clase GastosGeneralesBL
 *
 * @package    
 * @subpackage 
 * @author     GastosGeneralesBL
 * @version    SVN: $Id: GastosGeneralesBL.class.php,v 1.1 2008/02/08 21:56:44 william.taype Exp $ 
 */
class GastosGeneralesBL{
    
  /**
  * 
  *
  * @param $o_GastosGeneralesBean, objeto de tipo GastosGenerales 
  * @return Boolean
  */
  public function busquedaGastosGenerales(GastosGeneralesBean $o_GastosGeneralesBean){
    
    $o_GastosGeneralesDP = new GastosGeneralesDP($o_GastosGeneralesBean);
    if($o_GastosGeneralesBean->getIdGasto()){
      return $o_GastosGeneralesDP->selectByPk();
    }else{
      return $o_GastosGeneralesDP->select();
    }
    
  }
  
  public function busquedaGastosGeneralesResulset(GastosGeneralesBean $o_GastosGeneralesBean){
    
    $o_GastosGeneralesDP = new GastosGeneralesDP($o_GastosGeneralesBean);
    return $o_GastosGeneralesDP->selectResultset();
        
  }
  
  public function insertarGastosGenerales(GastosGeneralesBean $o_GastosGeneralesBean){
    
    $o_GastosGeneralesCT = new GastosGeneralesCT();
    return $o_GastosGeneralesCT->guardar($o_GastosGeneralesBean);
    
  }
  public function modificarGastosGenerales(GastosGeneralesBean $o_GastosGeneralesBean){
      $o_GastosGeneralesCT = new GastosGeneralesCT();
      return $o_GastosGeneralesCT->modificar($o_GastosGeneralesBean);
  }
  /**
	* Función que retorna un objeto GastosGenerales o una lista de Objetos de GastosGenerales,
	* dependiendo del parametro que se le envia si este contiene o no el Id de GastosGenerales
	*
	* @param $o_GastosGeneralesBean, es un objeto de tipo GastosGenerales
	* @return Object
	*/
	
  
  public function eliminarGastosGenerales(GastosGeneralesBean $o_GastosGeneralesBean){
    $o_GastosGeneralesCT = new GastosGeneralesCT();
    return $o_GastosGeneralesCT->eliminar($o_GastosGeneralesBean);
    
  }
  
  public function getCountResult(GastosGeneralesBean $o_GastosGeneralesBean){
    $o_GastosGeneralesCT = new GastosGeneralesCT();
    return $o_GastosGeneralesCT->totalRegistros($o_GastosGeneralesBean);
  }
  
}

