<?php

class GastosGeneralesSystemClass {

  private $o_ParamBean;
  
  public function __construct($o_ParamBean){
    $this->o_ParamBean = $o_ParamBean;
  }
  
  private function getObjParamBean(){
    return $this->o_ParamBean;
  }
  
  public function insertGastosGenerales(){
    
    $o_GastosGeneralesBL = new GastosGeneralesBL();
    return $o_GastosGeneralesBL->insertarGastosGenerales($this->getObjParamBean());
    
  }
  
  public function insertUsuario($o_UsuarioBean){
    $o_UsuarioBL = new UsuarioBL();
    $o_UsuarioBL->insertarUsuario($o_UsuarioBean);
  }
   
  public function eliminarGastosGenerales(){
    
    $o_GastosGeneralesBL = new GastosGeneralesBL();
    return $o_GastosGeneralesBL->eliminarGastosGenerales($this->getObjParamBean());
    
  }
  
  public function actualizarGastosGenerales(){
    
    $o_GastosGeneralesBL = new GastosGeneralesBL();
    return $o_GastosGeneralesBL->modificarGastosGenerales($this->getObjParamBean());
    
  }
  
  public function getGastosGenerales(){
  
    $o_GastosGeneralesBL = new GastosGeneralesBL();
    return $o_GastosGeneralesBL->busquedaGastosGenerales($this->getObjParamBean());
  
  }
   
  public function getColaborador(){
    $o_ColaboradorBL = new ColaboradorBL();
    return $o_ColaboradorBL->busquedaColaborador(new ColaboradorBean());
    
  }
  public function getGrado(){
    $o_GradoBL = new GradoBL();
    return $o_GradoBL->busquedaGrado(new GradoBean());
    
  }
  public function getSucursal(){
    
    $o_SucursalBL = new SucursalBL();
    return $o_SucursalBL->busquedaSucursal(new SucursalBean());
  }
  
  public function getEspecialidad(){
    
    $o_EspecialidadBL = new EspecialidadBL();
    return $o_EspecialidadBL->getEspecialidad($this->getObjParamBean());
  }

}